i18n
----

Pre-requirements::

    sudo pip install Babel
    sudo pip install lingua

POT extraction::

    python setup.py extract_messages

Initial catalog creations::

    python setup.py init_catalog -l [en|de|...]

Updating translation::

    python setup.py extract_messages
    python setup.py update_catalog

Compile catalog::

    python setup.py compile_catalog
